(($, Drupal, once) => {
  Drupal.behaviors.password_policy_extras = {
    attach(context, settings) {
      once(
        "password_policy_extras",
        'input[name="pass[pass1]"]',
        context
      ).forEach(element => {
        // Accessibility improvements.
        element.setAttribute("aria-describedby", "password-policy-status");
        const ajaxBeforeSendOriginal = Drupal.Ajax.prototype.beforeSend;
        Drupal.Ajax.prototype.beforeSend = (...args) => {
          ajaxBeforeSendOriginal.apply(this, args);
          // We want to be able to properly continue entering the password.
          // So we need to avoid the field being disabled and losing focus.
          $(element).prop("disabled", false);
          $(element).focus();
        };
        const delay = settings.password_policy_extras.status_refresh_delay;
        if (parseInt(delay, 10) > 0) {
          const self = $(element);
          let timeout = null;
          // The 'input' event fires when the value of the input has been
          // changed as a direct action of a user such as typing.
          self.off("input").on("input", () => {
            clearTimeout(timeout);
            timeout = setTimeout(() => {
              // Triggers the default Password Policy 'change' Ajax handling.
              self.trigger("change");
            }, delay);
          });
        }
      });
    }
  };
})(jQuery, Drupal, once);
